## Demand in the UK

### Description

We have access to data from a random sample of grocery stores in the UK. The data includes information on unit sales in a category during one month in each store in a store panel in the UK. The data set contains one variable, 'demand_uk'. 

### Variables

A data frame with 572 observations on 2 variable

* id = Store identifier
* demand = Total category sales in units per store